%%%%%%%%%%   
% make a model of the expected response of LHO HAM6 ISI
%%%%%%%%%%%
clear
close all


%% setup the local environment
printNoiseFigs = false;
printRMSFigs = false;
printDispFigs = false;

date_str = '100329';

[blah, me] = system('whoami');
if strncmpi(me,'BTL',3)
    mySVN = '/Users/BTL/Brians_files/SeismicSVN/seismic/';
else
    mySVN = 'put your home path here';
end

%    mySVN = 'C:\Ben\MatlabStuff\BenVN\';
SVNtools = 'HAM-ISI/Common/MatlabTools/';
addpath([mySVN, SVNtools])
addpath([mySVN, SVNtools,'HEPI_motion'])

set(0,'DefaultAxesFontSize',20)
my_colors;

%%

disp(' ')
disp(['running ',mfilename,' on ',date])

freq = (1e-2:0.005:1e2)';
w    = 2*pi*freq;
g    = 9.8;

%%  cap sensor noise
ADC_volt_noise = SEI_sensor_noise('ADC',freq);  % this is in V/rtHz
disp_sensor_noise = SEI_sensor_noise('ADE_1mm',freq); 
disp_sensor_noise_ideal = ones(size(disp_sensor_noise)) * disp_sensor_noise(end);

BSCreq = BSC_req(freq);

disp_sensitivity = 1e-3 /(2*10); % m/V, because 1 mm is 10 V, *2 for diff input, ie 1 mm is 20 V diff

disp_ADC_noise = ADC_volt_noise .* disp_sensitivity;


% the noise in the Z sensor should  be related to the noise in each
% (idential) geophone, N1, as:
%    Nz = N1 * sqrt(0.332 + 0.332 + 0.332) = 0.57 * N1
% For the 6 DOFs, this works out to be:
%       X: 0.8172
%       Y: 0.8172
%       Z: 0.5774
%       RX: 1.037
%       RY: 1.037
%       Rz: 0.8497 
%
% so the if the allowed tilt noise is tilt_req,
% then the noise in a vertical sensor is tilt_req = 1.037 * N1
% N1 = ( X_req * w^2/g ) * (1/1.037)
rx_scale = 1/1.037;
tilt_req = (BSCreq .* (w.^2) ./ g) * rx_scale;

disp_fig = figure;
ll = loglog(...
    freq, BSCreq,'r',...
    freq, tilt_req,'r--',...)
    freq, disp_ADC_noise,'m',...
    freq, disp_sensor_noise,'b',...;
    freq, disp_sensor_noise_ideal,'b--');
set(ll,'LineWidth',2)
set(ll(1),'Color',dark_orange)
set(ll(2),'Color',dark_orange)
set(ll(4),'Color',[0 0 .6])

title('Noise on the 1 mm Displacement Sensor')
xlabel('freq (Hz)')
ylabel('motion ASD (m/rtHz)')
legend('BSC requirement','noise on vert. sensor causing tilt equal to BSC req.',...
    'ADC noise','measured noise A.Stein Nov 2008','ideal noise')
axis([1e-2 10 1e-11 1e-4])
grid on
FillPage('w')
IDfig

if printDispFigs == true;
    figure(disp_fig)
    filename = ['NoiseFigs_Disp_motion_',date_str,'.pdf'];
    print(disp_fig, '-dpdf', filename)
end


%% Geophones
GS13.genConst = 2279.1;      % Main coil generator constant
GS13.w0 = 2*pi*1;            % Resonant frequency

GS13.Rc = 9067;              % coil resistance
GS13.Rd = 845000;            % damping resistance D050358
        
GS13.Q = 4.5;
gs13Num = (GS13.Rd/(GS13.Rc+GS13.Rd)) * GS13.genConst * [1 0 0];
gs13Den = [1 GS13.w0/GS13.Q GS13.w0^2];

GS13.preamp_gain  = 2*20.0982;   % volts out/ volts in, low gain channel
                            % readout gain comes from (953+49.9)/49.9,
                            % (R2 + R1)/R1, in D050358 GS-13 Pre-Amp
                            % Revised 2007 Sep 20
                            % (The 2 comes from differential driver).
%
GS13.lowgain_whitening_zero = 10;  % Hz
GS13.lowgain_whitening_pole = 50;  % Hz
GS13.lowgain_DC_whitening_gain = 1;

GS13.AdLIGO_lowgain_whitening_filter = zpk(...
    -2*pi*GS13.lowgain_whitening_zero, ...
    -2*pi*GS13.lowgain_whitening_pole,...
    GS13.lowgain_DC_whitening_gain * GS13.lowgain_whitening_pole/GS13.lowgain_whitening_zero);


% the readout gain has the input stage and whitening stage (both above) and
% the x2 diff output stage. The 0.99 is from the voltage divider at the
% input, and if you can show me that the 1% ever matters I'll buy you a drink - BTL

GS13.lowgain_readout_gain = 2 * 0.99 * GS13.AdLIGO_lowgain_whitening_filter;


antialiasing_gain = 1;     % new aLIGO AA filters have DC gain of +1
                           % told to BTL on  March 2010
                           % We ignore the 500 Hz pole


% for the whole analog chain, up to the ADC input
GS13.lowgain_volt_per_mps = tf(gs13Num,gs13Den) * GS13.preamp_gain ... % volts / (meter / sec)
                                          * GS13.lowgain_readout_gain ...
                                          * antialiasing_gain;

GS13.lowgain_volt_per_mps_FR = squeeze(freqresp(GS13.lowgain_volt_per_mps,w));

GS13.lowgain_volt_per_m      = tf('s') * GS13.lowgain_volt_per_mps;
GS13.lowgain_volt_per_m_FR   = squeeze(freqresp(GS13.lowgain_volt_per_m,w));

%% and make the GS-13 preamp in use for enhanced LIGO
GS13.eLIGO_readout_gain   = 2 * 0.99 * 1;  % no zero-pole at 10-50 Hz
GS13.eLIGO_volt_per_mps   = tf(gs13Num,gs13Den) * GS13.preamp_gain ... % volts / (meter / sec)
                                          * GS13.eLIGO_readout_gain ...
                                          * antialiasing_gain;

GS13.eLIGO_volt_per_mps_FR   = squeeze(freqresp(GS13.eLIGO_volt_per_mps,w));

GS13.eLIGO_volt_per_m      = tf('s') * GS13.eLIGO_volt_per_mps;
GS13.eLIGO_volt_per_m_FR   = squeeze(freqresp(GS13.eLIGO_volt_per_m,w));

%%
%make a high-gain and whitening filter for better ADC performance
% parameters for a new whitening filter
% to improve the noise at high freq
GS13.highgain_whitening_zero = 50;  % Hz
GS13.highgain_whitening_pole = 50;  % Hz  % ie a flat gain of 6
GS13.highgain_DC_whitening_gain = 6;

GS13.AdLIGO_highgain_whitening_filter = zpk(...
    -2*pi*GS13.highgain_whitening_zero, ...
    -2*pi*GS13.highgain_whitening_pole,...
    GS13.highgain_DC_whitening_gain * GS13.highgain_whitening_pole/GS13.highgain_whitening_zero);

GS13.highgain_readout_gain = 2 * 0.99 * GS13.AdLIGO_highgain_whitening_filter;

figure
bode(GS13.AdLIGO_lowgain_whitening_filter, GS13.AdLIGO_highgain_whitening_filter)
title('New switchable filter for Advanced LIGO BSC GS-13s')
legend('low gain','high gain')

GS13.highgain_volt_per_mps    = tf(gs13Num,gs13Den) * GS13.preamp_gain ... % volts / (meter / sec)
                                          * GS13.highgain_readout_gain ...
                                          * antialiasing_gain;
%
GS13.highgain_volt_per_m      = tf('s') * GS13.highgain_volt_per_mps;

GS13.highgain_volt_per_mps_FR = squeeze(freqresp(GS13.highgain_volt_per_mps,w));
GS13.highgain_volt_per_m_FR   = 1i * w .* GS13.highgain_volt_per_mps_FR;

% this is only for the GS13 and preamp
% used to calculated signal size in the cables

GS13andpreamp.volt_per_mps    = tf(gs13Num,gs13Den) * GS13.preamp_gain;
GS13andpreamp.volt_per_mps_FR = squeeze(freqresp(GS13andpreamp.volt_per_mps,w));
GS13andpreamp.volt_per_m_FR   = 1i * w .* GS13andpreamp.volt_per_mps_FR;

%%

figure;
bode(tf(gs13Num,gs13Den))
title('LHO BSC ISI GS13 velocity response in Volts/ (meters/sec) (manufacturer''s units)')
legend(['genConst = ' num2str(GS13.genConst) 'V/(m/s), f_0 = ' num2str(GS13.w0/(2*pi)) 'Hz, ' ...
       'R_{coil} = ' num2str(GS13.Rc) '\Omega, R_{damp} = ' num2str(GS13.Rd) '\Omega, Q = ' num2str(GS13.Q)])
grid on
IDfig
FillPage('w')


%%
figure       % volts per meter per sec

subplot(211)
ll = loglog(freq,abs(GS13.lowgain_volt_per_mps_FR));
set(ll(1),'LineWidth',2);
title({'LHO BSC ISI GS13 velocity response - Lowgain' , 'V / (m/secs) at the ADC input'})
%legend('Manufacter Response * preamp gain * readout gain * aa gain')
grid on
axis([1e-2 1e2 1e1 2e6])

subplot(212)
ll = semilogx(freq,180/pi*angle(GS13.lowgain_volt_per_mps_FR));
set(ll(1),'LineWidth',2)
axis([1e-2 1e2 -2 182])
set(gca,'YTick',45*(0:4))
grid on
IDfig
FillPage('w')


%%
figure       % volts per meter

subplot(211)
ll = loglog(freq,abs(GS13.lowgain_volt_per_m_FR));
set(ll(1),'LineWidth',2);
title({'LHO BSC ISI GS13 displacement response - Lowgain' , 'V / m at the ADC input'})
%legend('Manufacter Response * preamp gain * readout gain * aa gain')
grid on

subplot(212)
ll = semilogx(freq,180/pi*angle(GS13.lowgain_volt_per_m_FR));
set(ll(1),'LineWidth',2)
axis([1e-2 1e2 -2 272])
set(gca,'YTick',45*(0:6))

grid on
IDfig
FillPage('w')

%%

GS13.noise_LT1012 = SEI_sensor_noise('GS13calc',freq);


GS13.lowgain_noise_ADC  = ADC_volt_noise ./ abs(GS13.lowgain_volt_per_m_FR);
GS13.highgain_noise_ADC = ADC_volt_noise ./ abs(GS13.highgain_volt_per_m_FR);

GS13.noise_ETF = SEI_sensor_noise('GS13meas',freq);

BSCreq = BSC_req(freq);

ground_motion_LLO = Ligo2GroundMotionL(freq);

%%
f2_index = find(freq>.1);

GS13_motionNoise_fig = figure;
ll=loglog(...
    freq(f2_index), ground_motion_LLO(f2_index),...
    freq, BSCreq, 'r',...
    freq, GS13.noise_ETF,'b--',...
    freq, GS13.noise_LT1012,'b',...
    freq, GS13.lowgain_noise_ADC,'m--',...
    freq, GS13.highgain_noise_ADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0]);
set(ll(2),'Color',dark_orange);
set(ll(3),'Color',[0 0 1]);
grid on
legend(...
    'LLO ground motion estimate',...
    'BSC motion requirement',...
    'GS13 noise measured at ETF',...
    'GS13 calculated noise',...
    'ADC noise, low-gain',...
    'ADC noise, high-gain')
title('Noise performace of the GS-13 and ADC for Advanced LIGO BSC')
xlabel('freq (Hz)')
ylabel('noise ASD (m/\surdHz)')
axis([.03 1e2 1e-14 1e-6])
set(gca,'YTick',[1e-14,1e-13, 1e-12, 1e-11, 1e-10, 1e-9, 1e-8, 1e-7, 1e-6]);
IDfig
FillPage('w')


%%
% look at signal sizes at the ADC input
GS13.ADC_noise_atADC        = ADC_volt_noise;
GS13.lowgain_noise_atADC    = GS13.noise_ETF    .* abs(GS13.lowgain_volt_per_m_FR);
GS13.highgain_noise_atADC   = GS13.noise_LT1012 .* abs(GS13.highgain_volt_per_m_FR);
GS13.BSC_lowgain_req_atADC  = BSCreq            .* abs(GS13.lowgain_volt_per_m_FR);
GS13.BSC_highgain_req_atADC = BSCreq            .* abs(GS13.highgain_volt_per_m_FR);
GS13.noise_incable          = GS13.noise_LT1012 .* abs(GS13andpreamp.volt_per_m_FR);
ground_motion_LLO_lowgain_atADC   = ground_motion_LLO .* abs(GS13.lowgain_volt_per_m_FR);
ground_motion_LLO_highgain_atADC  = ground_motion_LLO .* abs(GS13.highgain_volt_per_m_FR);

%%
BW = [freq(2) - freq(1); freq(2:end) - freq(1:end-1)];

gnd_power_lowgain                    = BW .* (ground_motion_LLO_lowgain_atADC.^2);
gnd_power_highgain                   = BW .* (ground_motion_LLO_highgain_atADC.^2);

ground_motion_LLO_lowgain_atADC_RMS  = reverse(sqrt(cumsum(reverse(gnd_power_lowgain))));
ground_motion_LLO_highgain_atADC_RMS = reverse(sqrt(cumsum(reverse(gnd_power_highgain))));

%%
% we will make 3 figure, a lowgain, a highgain, and a reduced combo

GS13_ADCNoiselowgain_fig = figure;   % lowgain GS13 figure
ll =loglog(...
    freq(f2_index), ground_motion_LLO_lowgain_atADC(f2_index), ...
    freq(f2_index), ground_motion_LLO_lowgain_atADC_RMS(f2_index),...
    freq, GS13.BSC_lowgain_req_atADC, ...
    freq, GS13.noise_incable, ...
    freq, GS13.lowgain_noise_atADC, 'b--',...
    freq, GS13.ADC_noise_atADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0])
set(ll(2),'Color',[0 .7 0],'LineStyle','--');
set(ll(3),'Color',dark_orange)
set(ll(4),'Color',purple)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input, LOW GAIN', 'GS-13 on Advanced LIGO BSC-ISI'})
leg=legend(...
    'LLO ground motion, as measured by a lowgain GS-13',...
    'RMS of LLO ground motion with a lowgain GS-13',...
    'BSC requirement, measured by lowgain GS-13, at ADC',...
    'GS13 calculated noise, at the start of the long cable',...
    'Measured GS13 noise, with lowgain filter, at ADC',...
    'ADC input noise');
set(leg,'FontSize',14)
grid on
axis([.03 100 5e-7 10])
IDfig
FillPage('w')


GS13_ADCNoisehighgain_fig = figure;   % highgain GS13 figure
ll =loglog(...
    freq(f2_index), ground_motion_LLO_highgain_atADC(f2_index), ...
    freq(f2_index), ground_motion_LLO_highgain_atADC_RMS(f2_index),...
    freq, GS13.BSC_highgain_req_atADC, ...
    freq, GS13.noise_incable, ...
    freq, GS13.highgain_noise_atADC, 'b',...
    freq, GS13.ADC_noise_atADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0])
set(ll(2),'Color',[0 .7 0],'LineStyle','--');
set(ll(3),'Color',dark_orange)
set(ll(4),'Color',purple)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input - HIGH GAIN', 'GS-13 on Advanced LIGO BSC-ISI'})
leg=legend(...
    'LLO ground motion, as measured by a highgain GS-13',...
    'RMS of LLO ground motion with a highgain GS-13',...
    'BSC requirement, measured by highgain GS-13, at ADC',...
    'GS13 calculated noise, at the start of the long cable',...
    'Calculated GS13 noise, with highgain filter, at ADC',...
    'ADC input noise');
set(leg,'FontSize',14)
grid on
axis([.03 100 5e-7 10])
IDfig
FillPage('w')

GS13_ADCNoisecombo_fig = figure;   % combo GS13 figure
ll =loglog(...
    freq, GS13.BSC_highgain_req_atADC, ...
    freq, GS13.BSC_lowgain_req_atADC, 'r--',...
    freq, GS13.noise_incable, ...
    freq, GS13.highgain_noise_atADC, 'b',...
    freq, GS13.lowgain_noise_atADC, 'b--',...
    freq, GS13.ADC_noise_atADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',dark_orange)
set(ll(2),'Color',dark_orange)
set(ll(3),'Color',purple)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input - Gain Comparisons', 'GS-13 on Advanced LIGO BSC-ISI'})
leg=legend(...
    'BSC requirement, measured by highgain GS-13, at ADC',...
    'BSC requirement, measured by lowgain GS-13, at ADC',...
    'GS13 calculated noise, at the start of the long cable',...
    'Calculated GS13 noise, with highgain filter, at ADC',...
    'Measured GS13 noise, with lowgain filter, at ADC',...
    'ADC input noise');
set(leg,'FontSize',14)
grid on
axis([.03 100 5e-7 .1])
IDfig
FillPage('w')


% figure(10); print -dpdf GS13_noise_mprtHz.pdf
% figure(11); print -dpdf GS13_noise_atADC.pdf


%% do the T-240
% differential output is 1200 V/m/s

T240.genConst = 1200;   % output in V/m/s
w0 = 2*pi*1/240;            % Resonant frequency
T240.zeros = [0,0,-108,-161]; %see pg 10 of the OBS user guide

T240.poles = [...
    -0.01815 + 0.01799i , -0.01815 - 0.01799i,...
    -173,...
    -196 +  231i, -196 -  231i,...
    -732 + 1415i, -732 - 1415i];

T240.k = 1196.5 * 2.316e9;

T240.velocity_tf = zpk(T240.zeros, T240.poles, T240.k);

T240.disp_tf = tf('s') * T240.velocity_tf;

figure
bode(T240.velocity_tf)
title('velocity response of the T-240')

figure
bode(T240.disp_tf)
title('displacement response of the T-240')


%%

LASTI_target_gain = 2.1 * 42 * 1500/1196;  % AA times readout time STS-2 sens/T240 sens
disp(['To match the LASTI signals, the T240 gain should be ',num2str(LASTI_target_gain)]) 


T240.readout_gain = 113;     % LASTI has 42 for the STS-2
disp(['For aLIGO, we will try ',num2str(T240.readout_gain)]) 



T240.antialiasing_gain = 1;     % AdL AA and AI Filter D070081 Rev 1
                            % 2007 July 2
                            % We ignore the 500 Hz pole

% for the whole analog chain, up to the ADC input
T240.volt_per_mps = T240.velocity_tf * T240.readout_gain * T240.antialiasing_gain;
T240.volt_per_m   = T240.disp_tf     * T240.readout_gain * T240.antialiasing_gain;

%

T240.volt_per_mps_FR = squeeze(freqresp(T240.volt_per_mps,w));
T240.volt_per_m_FR   = squeeze(freqresp(T240.volt_per_m,  w));

%%
T240.noise_spec = SEI_sensor_noise('T240spec',freq);
T240.noise_meas = SEI_sensor_noise('T240meas',freq);

%ADC_volt_noise = 4e-6;

T240.ADC_noise = ADC_volt_noise ./ abs(T240.volt_per_m_FR);

%%
f240_index = find((freq > .020) & (freq < 40));

T240_motionNoise_fig = figure;
ll=loglog(...
    freq(f2_index), ground_motion_LLO(f2_index),...
    freq(f240_index), BSCreq(f240_index), 'r',...
    freq(f240_index), T240.noise_meas(f240_index),'b--',...
    freq(f240_index), T240.noise_spec(f240_index),'b',...
    freq(f240_index), T240.ADC_noise(f240_index),'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0]);
set(ll(2),'Color',dark_orange);
set(ll(3),'Color',[0 0 1]);
set(ll(4),'Color',[0 0 .7]);
grid on
legend(...
    'LLO ground motion estimate',...
    'BSC motion requirement',...
    'T240 noise measured at ETF',...
    'T240 noise specification',...
    'ADC noise, low-gain')
title('Noise performace of the T-240 and ADC')
xlabel('freq (Hz)')
ylabel('noise ASD (m/\surdHz)')
axis([.02 1e2 1e-13 1e-5])
set(gca,'YTick',[1e-13, 1e-12, 1e-11, 1e-10, 1e-9, 1e-8, 1e-7, 1e-6, 1e-5]);
IDfig
FillPage('w')


%%
% look at signal sizes at the ADC input
T240.ADC_noise_atADC  = ADC_volt_noise;
T240.noise_spec_atADC = T240.noise_spec .* abs(T240.volt_per_m_FR);
T240.noise_meas_atADC = T240.noise_meas .* abs(T240.volt_per_m_FR);
T240.BSC_req_atADC    = BSCreq          .* abs(T240.volt_per_m_FR);
T240.ground_motion_LLO_atADC = ground_motion_LLO .* abs(T240.volt_per_m_FR);

%%
BW = [freq(2) - freq(1); freq(2:end) - freq(1:end-1)];
T240.gnd_power = BW .* (T240.ground_motion_LLO_atADC.^2);
T240.ground_motion_LLO_atADC_RMS = reverse(sqrt(cumsum(reverse(T240.gnd_power))));

%%


T240_ADCNoise_fig = figure;
ll =loglog(...
    freq(f2_index), T240.ground_motion_LLO_atADC(f2_index), ...
    freq(f2_index), T240.ground_motion_LLO_atADC_RMS(f2_index),...
    freq, T240.BSC_req_atADC, ...
    freq, T240.noise_spec_atADC, 'b',...
    freq, T240.ADC_noise_atADC, 'm');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0])
set(ll(2),'Color',[0 .7 0],'LineStyle','--');
set(ll(3),'Color',dark_orange)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input', 'T240 on AdLIGO BSC-ISI (w/ gain of 100)'})
leg=legend(...
    'LLO ground motion, as measured by a T-240',...
    'RMS of LLO ground motion with T-240',...
    'BSC requirement, measured by T-240, at ADC',...
    'noise spec for T-240',...
    'ADC input noise');
set(leg,'FontSize',16)
grid on
axis([.03 100 1e-6 3])
IDfig
FillPage('w')

%% and the L4Cs

% the generator constant is 7.02 volts/in/sec = 276.3780 V*s/m (spec sheet)
L4C.genConst = 7.02 /.0254; % Main coil generator constant

L4C.w0 = 2*pi*1;            % Resonant frequency

L4C.Rc = 5500;              % coil resistance
L4C.Rd = 100000;            % damping resistance D050358

L4C.b0   = .28;           % open circuit damping, from the spec sheet
L4C.bc = 1.1*L4C.Rc/(L4C.Rc+L4C.Rd);   % damping from external resistor
L4C.bt = L4C.b0 + L4C.bc;          % total damping


L4C.Q = 1/(2*L4C.bt);
L4CNum = (L4C.Rd/(L4C.Rc+L4C.Rd)) * L4C.genConst * [1 0 0];
L4CDen = [1 L4C.w0/L4C.Q L4C.w0^2];

% L4C preamp is D1000059
L4C.preamp_gain  = 2 * 2*11;   % volts out/ volts in, new 2 on March 22, 2010 from BTL & BenA

% calculate the gain to match the GS-13s on HAM-ISI
GS13_HAMsens = GS13.genConst * GS13.preamp_gain * abs(squeeze(freqresp(GS13.lowgain_readout_gain,0))) ; % V/m/s above 1 Hz, AA gain is 1 for HAMISI
L4C_target_readout_gain = GS13_HAMsens/(L4C.genConst * L4C.preamp_gain);
disp(['target gain for the L4C, to match the HAM-ISI GS-13s, would be ',...
    num2str(L4C_target_readout_gain)])
disp('gain for LASTI is 2 (x1 for readout, x2 at LASTI AA')

% 2 is from diff readout, 0.99 is passive divider at input, instamp gain is 1, 
L4C.lowgain_readout_gain =  2 * 0.99 * 1;   %L4C interface is D070126 

disp(['running with a readout gain of ',num2str(L4C.lowgain_readout_gain)])

antialiasing_gain = 1;     % new aLIGO AA filters have DC gain of +1
                           % told to BTL on  March 2010
                           % We ignore the 500 Hz pole


% for the whole analog chain, up to the ADC input
L4C.lowgain_volt_per_mps = tf(L4CNum,L4CDen) * L4C.preamp_gain ... % volts / (meter / sec)
                                          * L4C.lowgain_readout_gain ...
                                          * antialiasing_gain;


L4C.lowgain_volt_per_mps_FR = squeeze(freqresp(L4C.lowgain_volt_per_mps,w));

L4C.lowgain_volt_per_m      = tf('s') * L4C.lowgain_volt_per_mps;
L4C.lowgain_volt_per_m_FR   = squeeze(freqresp(L4C.lowgain_volt_per_m,w));

%%
%make a high-gain and whitening filter for better ADC performance
% parameters for a new whitening filter
% to improve the noise at high freq
L4C.whitening_zero = 50;  % Hz
L4C.whitening_pole = 50;  % Hz
L4C.DC_whitening_gain = 7;

L4C.AdLIGO_highgain_whitening_filter = zpk(-2*pi*L4C.whitening_zero, ...
    -2*pi*L4C.whitening_pole,...
    L4C.DC_whitening_gain * L4C.whitening_pole/L4C.whitening_zero);

% 2 is from diff readout, 0.99 is passive divider at input, and the input
% stage 
L4C.highgain_readout_gain =  2 * 0.99 * L4C.AdLIGO_highgain_whitening_filter;   % 

figure
bode(tf(L4C.lowgain_readout_gain), L4C.highgain_readout_gain)
title('New switchable filter for Advanced LIGO BSC GS-13s')
legend('low gain','high gain')

L4C.highgain_volt_per_mps = tf(L4CNum,L4CDen) * L4C.preamp_gain ... % volts / (meter / sec)
                                          * L4C.highgain_readout_gain ...
                                          * antialiasing_gain;
%
L4C.highgain_volt_per_m = tf('s') * L4C.highgain_volt_per_mps;

L4C.highgain_volt_per_mps_FR = squeeze(freqresp(L4C.highgain_volt_per_mps,w));
L4C.highgain_volt_per_m_FR   = 1i * w .* L4C.highgain_volt_per_mps_FR;

%%
% this is only for the L4C and preamp
% used to calculated signal size in the cables

L4Candpreamp.volt_per_mps    = tf(L4CNum,L4CDen) * L4C.preamp_gain;
L4Candpreamp.volt_per_mps_FR = squeeze(freqresp(L4Candpreamp.volt_per_mps,w));
L4Candpreamp.volt_per_m_FR   = 1i * w .* L4Candpreamp.volt_per_mps_FR;

%%

figure;
bode(tf(L4CNum,L4CDen))
title('LHO BSC ISI L4C velocity response in Volts/ (meters/sec) (manufacturer''s units)')
legend(['genConst = ' num2str(L4C.genConst) 'V/(m/s), f_0 = ' num2str(L4C.w0/(2*pi)) 'Hz, ' ...
       'R_{coil} = ' num2str(L4C.Rc) '\Omega, R_{damp} = ' num2str(L4C.Rd) '\Omega, Q = ' num2str(L4C.Q)])
grid on
IDfig
FillPage('w')


%%
figure       % volts per meter per sec

subplot(211)
ll = loglog(freq,abs(L4C.lowgain_volt_per_mps_FR));
set(ll(1),'LineWidth',2);
title({'LHO BSC ISI L4C velocity response - Lowgain' , 'V / (m/secs) at the ADC input'})
%legend('Manufacter Response * preamp gain * readout gain * aa gain')
grid on
axis([1e-2 1e2 1e1 2e6])

subplot(212)
ll = semilogx(freq,180/pi*angle(L4C.lowgain_volt_per_mps_FR));
set(ll(1),'LineWidth',2)
axis([1e-2 1e2 -2 182])
set(gca,'YTick',45*(0:4))
grid on
IDfig
FillPage('w')


%%
figure       % volts per meter

subplot(211)
ll = loglog(freq,abs(L4C.lowgain_volt_per_m_FR));
set(ll(1),'LineWidth',2);
title({'LHO BSC ISI L4C displacement response - Lowgain' , 'V / m at the ADC input'})
%legend('Manufacter Response * preamp gain * readout gain * aa gain')
grid on

subplot(212)
ll = semilogx(freq,180/pi*angle(L4C.lowgain_volt_per_m_FR));
set(ll(1),'LineWidth',2)
axis([1e-2 1e2 -2 272])
set(gca,'YTick',45*(0:6))

grid on
IDfig
FillPage('w')

%%

L4C.noise = SEI_sensor_noise('L4C',freq);

L4C.lowgain_noise_ADC  = ADC_volt_noise ./ abs(L4C.lowgain_volt_per_m_FR);
L4C.highgain_noise_ADC = ADC_volt_noise ./ abs(L4C.highgain_volt_per_m_FR);


%%
f2_index = find(freq>.1);

L4C_motionNoise_fig = figure;
ll=loglog(...
    freq(f2_index), ground_motion_LLO(f2_index),...
    freq, BSCreq, 'r',...
    freq, L4C.noise,'b',...
    freq, L4C.lowgain_noise_ADC,'m--',...
    freq, L4C.highgain_noise_ADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0]);
set(ll(2),'Color',dark_orange);
set(ll(3),'Color',[0 0 1]);
grid on
legend(...
    'LLO ground motion estimate',...
    'BSC motion requirement',...
    'L4C noise',...
    'ADC noise, low-gain',...
    'ADC noise, high-gain')
title('Noise performace of the L-4C and ADC for Advanced LIGO BSC')
xlabel('freq (Hz)')
ylabel('noise ASD (m/\surdHz)')
axis([.03 1e2 1e-14 1e-6])
set(gca,'YTick',[1e-14,1e-13, 1e-12, 1e-11, 1e-10, 1e-9, 1e-8, 1e-7, 1e-6]);
IDfig
FillPage('w')


%%
% look at signal sizes at the ADC input
L4C.ADC_noise_atADC        = ADC_volt_noise;
L4C.lowgain_noise_atADC    = L4C.noise  .* abs(L4C.lowgain_volt_per_m_FR);
L4C.highgain_noise_atADC   = L4C.noise  .* abs(L4C.highgain_volt_per_m_FR);
L4C.BSC_lowgain_req_atADC  = BSCreq     .* abs(L4C.lowgain_volt_per_m_FR);
L4C.BSC_highgain_req_atADC = BSCreq     .* abs(L4C.highgain_volt_per_m_FR);
L4C.noise_incable          = L4C.noise  .* abs(L4Candpreamp.volt_per_m_FR);
ground_motion_LLO_lowgain_atADC   = ground_motion_LLO .* abs(L4C.lowgain_volt_per_m_FR);
ground_motion_LLO_highgain_atADC  = ground_motion_LLO .* abs(L4C.highgain_volt_per_m_FR);

%%
BW = [freq(2) - freq(1); freq(2:end) - freq(1:end-1)];

gnd_power_lowgain                    = BW .* (ground_motion_LLO_lowgain_atADC.^2);
gnd_power_highgain                   = BW .* (ground_motion_LLO_highgain_atADC.^2);

ground_motion_LLO_lowgain_atADC_RMS  = reverse(sqrt(cumsum(reverse(gnd_power_lowgain))));
ground_motion_LLO_highgain_atADC_RMS = reverse(sqrt(cumsum(reverse(gnd_power_highgain))));

%%
% we will make 3 figure, a lowgain, a highgain, and a reduced combo

L4C_ADCNoiselowgain_fig = figure;   % lowgain L4C figure
ll =loglog(...
    freq(f2_index), ground_motion_LLO_lowgain_atADC(f2_index), ...
    freq(f2_index), ground_motion_LLO_lowgain_atADC_RMS(f2_index),...
    freq, L4C.BSC_lowgain_req_atADC, ...
    freq, L4C.noise_incable, ...
    freq, L4C.lowgain_noise_atADC, 'b--',...
    freq, L4C.ADC_noise_atADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0])
set(ll(2),'Color',[0 .7 0],'LineStyle','--');
set(ll(3),'Color',dark_orange)
set(ll(4),'Color',purple)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input, LOW GAIN', 'L-4C on Advanced LIGO BSC-ISI'})
leg=legend(...
    'LLO ground motion, as measured by a lowgain L-4C',...
    'RMS of LLO ground motion with a lowgain L-4C',...
    'BSC requirement, measured by lowgain L-4C, at ADC',...
    'L-4C noise, at the start of the long cable',...
    'L-4C noise, with lowgain filter, at ADC',...
    'ADC input noise');
set(leg,'FontSize',14)
grid on
axis([.03 100 5e-7 10])
IDfig
FillPage('w')



L4C_ADCNoisehighgain_fig = figure;   % highgain L4C figure
ll =loglog(...
    freq(f2_index), ground_motion_LLO_highgain_atADC(f2_index), ...
    freq(f2_index), ground_motion_LLO_highgain_atADC_RMS(f2_index),...
    freq, L4C.BSC_highgain_req_atADC, ...
    freq, L4C.noise_incable, ...
    freq, L4C.highgain_noise_atADC, 'b',...
    freq, L4C.ADC_noise_atADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',[0 .7 0])
set(ll(2),'Color',[0 .7 0],'LineStyle','--');
set(ll(3),'Color',dark_orange)
set(ll(4),'Color',purple)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input - HIGH GAIN', 'L-4C on Advanced LIGO BSC-ISI'})
leg=legend(...
    'LLO ground motion, as measured by a highgain L-4C',...
    'RMS of LLO ground motion with a highgain L-4C',...
    'BSC requirement, measured by highgain L-4C, at ADC',...
    'L-4C noise, at the start of the long cable',...
    'L-4C noise, with highgain filter, at ADC',...
    'ADC input noise');
set(leg,'FontSize',14)
grid on
axis([.03 100 5e-7 10])
IDfig
FillPage('w')

L4C_ADCNoisecombo_fig = figure;   % combo L4C figure
ll =loglog(...
    freq, L4C.BSC_highgain_req_atADC, ...
    freq, L4C.BSC_lowgain_req_atADC, 'r--',...
    freq, L4C.noise_incable, ...
    freq, L4C.highgain_noise_atADC, 'b',...
    freq, L4C.lowgain_noise_atADC, 'b--',...
    freq, L4C.ADC_noise_atADC,'m');
set(ll,'LineWidth',2)
set(ll(1),'Color',dark_orange)
set(ll(2),'Color',dark_orange)
set(ll(3),'Color',purple)
xlabel('freq (Hz)')
ylabel('voltage noise ASD (V/\surdHz) or volts RMS')
title({'Signal levels at the ADC input - Gain Comparisons', 'L-4C on Advanced LIGO BSC-ISI'})
leg=legend(...
    'BSC requirement, measured by highgain L-4C, at ADC',...
    'BSC requirement, measured by lowgain L-4C, at ADC',...
    'L-4C noise, at the start of the long cable',...
    'L-4C noise, with highgain filter, at ADC',...
    'L-4C noise, with lowgain filter, at ADC',...
    'ADC input noise');
set(leg,'FontSize',14)
grid on
axis([.03 100 5e-7 .1])
IDfig
FillPage('w')


%%
if printNoiseFigs == true
    % these are the GS13 figures
    figure(GS13_motionNoise_fig)
    filename = ['NoiseFigs_GS13_motion_',date_str,'.pdf'];
    print(GS13_motionNoise_fig, '-dpdf', filename)
    
    figure(GS13_ADCNoiselowgain_fig)
    filename = ['NoiseFigs_GS13_ADClowgain_',date_str,'.pdf'];
    print(GS13_ADCNoiselowgain_fig, '-dpdf', filename)

    figure(GS13_ADCNoisehighgain_fig)
    filename = ['NoiseFigs_GS13_ADChighgain_',date_str,'.pdf'];
    print(GS13_ADCNoisehighgain_fig, '-dpdf', filename)

    figure(GS13_ADCNoisecombo_fig)
    filename = ['NoiseFigs_GS13_ADCcombo_',date_str,'.pdf'];
    print(GS13_ADCNoisecombo_fig, '-dpdf', filename)
    
    % print the T240 figures
    figure(T240_motionNoise_fig)
    filename = ['NoiseFigs_T240_motion_',date_str,'.pdf'];
    print(T240_motionNoise_fig, '-dpdf', filename)

    figure(T240_ADCNoise_fig)
    filename = ['NoiseFigs_T240_ADC_',date_str,'.pdf'];
    print(T240_ADCNoise_fig, '-dpdf', filename)

    
    
    % print the L4C figures
    figure(L4C_motionNoise_fig)
    filename = ['NoiseFigs_L4C_motion_',date_str,'.pdf'];
    print(L4C_motionNoise_fig, '-dpdf', filename)
    
    figure(L4C_ADCNoiselowgain_fig)
    filename = ['NoiseFigs_L4C_ADClowgain_',date_str,'.pdf'];
    print(L4C_ADCNoiselowgain_fig, '-dpdf', filename)

    figure(L4C_ADCNoisehighgain_fig)
    filename = ['NoiseFigs_L4C_ADChighgain_',date_str,'.pdf'];
    print(L4C_ADCNoisehighgain_fig, '-dpdf', filename)

    figure(L4C_ADCNoisecombo_fig)
    filename = ['NoiseFigs_L4C_ADCcombo_',date_str,'.pdf'];
    print(L4C_ADCNoisecombo_fig, '-dpdf', filename)

end  % print the noise figures

%%  look at some signal scaling issues

load('BSC_motion_data_100326.mat')  % see SEI log entry 1700, has data from HAM6ISI and LASTI


%% the GS-13s on HAM6 are a 'test case' of something that works

GS13rms.freq = HAMdata090605.XISI_free.freq';
%GS13rms.Zfreq = HAMdata090605.ZISI_free.freq;  %this is the same as the X data

GS13rms.GS13resp = abs(squeeze(freqresp(GS13.eLIGO_volt_per_m,2*pi*GS13rms.freq)));

GS13rms.X_ADC_asd = GS13rms.GS13resp .* HAMdata090605.XISI_free.asdData';
GS13rms.Z_ADC_asd = GS13rms.GS13resp .* HAMdata090605.ZISI_free.asdData';

% rms of the signal at the ADC, HAM6ISI from the lowgain GS13
GS13rms.Xrms = reverse(sqrt(cumsum(reverse(GS13rms.X_ADC_asd.^2))));
GS13rms.Zrms = reverse(sqrt(cumsum(reverse(GS13rms.Z_ADC_asd.^2))));

%%
GS13HAM_range_fig = figure;
ll=loglog(...
    GS13rms.freq, GS13rms.X_ADC_asd,'b',...
    GS13rms.freq, GS13rms.Xrms,'b--',...
    GS13rms.freq, GS13rms.Z_ADC_asd,'m',...
    GS13rms.freq, GS13rms.Zrms,'m--');
set(ll,'LineWidth',2)
title({'Signal levels from the HAM6-ISI GS-13s (090605 data)','System Not Damped, measured at the ADC in low-gain mode'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.1 100 1e-6 10])
FillPage('w')
IDfig
leg = legend(...
    'ASD of horizontal GS-13','integrated RMS of horizontal GS-13',...
    'ASD of vertical GS-13','integrated RMS of vertical GS-13',...
    'Location','SouthWest');
set(leg,'FontSize',18);

%% repeat the GS-13 on HAM6 with the damping ON
% load the 090605 damping data
LLO_data_path = [mySVN,'HAM-ISI/LLO/Data/'];

HAM6damped_data = load([LLO_data_path,'090605_L1PerformanceData.mat'],'freq','dampsOnly');
%%
GS13_dampedrms.freq = HAM6damped_data.freq';

GS13_dampedrms.GS13resp = abs(squeeze(freqresp(GS13.eLIGO_volt_per_m,2*pi*GS13_dampedrms.freq)));

GS13_dampedrms.X_ADC_asd = GS13_dampedrms.GS13resp .* HAM6damped_data.dampsOnly.geo.x;
GS13_dampedrms.Z_ADC_asd = GS13_dampedrms.GS13resp .* HAM6damped_data.dampsOnly.geo.z;

% rms of the signal at the ADC, HAM6ISI from the lowgain GS13
GS13_dampedrms.Xrms = reverse(sqrt(cumsum(reverse(GS13_dampedrms.X_ADC_asd.^2))));
GS13_dampedrms.Zrms = reverse(sqrt(cumsum(reverse(GS13_dampedrms.Z_ADC_asd.^2))));

%%
GS13HAM_damped_range_fig = figure;
ll=loglog(...
    GS13_dampedrms.freq, GS13_dampedrms.X_ADC_asd,'b',...
    GS13_dampedrms.freq, GS13_dampedrms.Xrms,'b--',...
    GS13_dampedrms.freq, GS13_dampedrms.Z_ADC_asd,'m',...
    GS13_dampedrms.freq, GS13_dampedrms.Zrms,'m--');
set(ll,'LineWidth',2)
title({'Signal levels from the HAM6-ISI GS-13s (090605 data)','Damping ON, expected at the ADC in low-gain mode'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.1 100 1e-6 10])
leg = legend(...
    'ASD of horizontal GS-13','integrated RMS of horizontal GS-13',...
    'ASD of vertical GS-13','integrated RMS of vertical GS-13',...
    'Location','SouthWest');
set(leg,'FontSize',18);
FillPage('w')
IDfig

%% now make the RMS estimates for the Observatories

%% plot the last X vs Z HEPI data
figure
ll=loglog(...
    BSCdataASPEpaper.XHEPI.freq,BSCdataASPEpaper.XHEPI.ASDdata,...
    BSCdataASPEpaper.ZHEPI.freq,BSCdataASPEpaper.ZHEPI.ASDdata,...
    BSCdataASPEpaper.Xground.freq,BSCdataASPEpaper.Xground.ASDdata);
set(ll,'LineWidth',2);
title('HEPI X is the problem direction at LASTI')
xlabel('freq (Hz)')
ylabel('LASTI motion ASD (m/rtHz)')
legend('X','Z','X ground')
grid on
axis([.05 100 1e-10 2e-6])
IDfig
FillPage('w')


%% estimate the motion of stage 2 at the observatory

ground_motion_LLO_LASTIfreq = Ligo2GroundMotionL(BSCdataASPEpaper.Xground.freq)';
GS13stg2freeRMS.freq = BSCdataASPEpaper.Xground.freq;

LLO_groundX_scaling = ground_motion_LLO_LASTIfreq ./ BSCdataASPEpaper.Xground.ASDdata';

figure
loglog(BSCdataASPEpaper.Xground.freq, LLO_groundX_scaling)
title('How much smaller is the LLO X ground motion than the LASTI X ground motion?')
xlabel('freq (Hz)')
ylabel('LLO model ASD/ LASTI ASPE paper ground X ASD')
grid on
axis([.1 100 .01 30])
IDfig
FillPage('w')

%% also make some guesses for HEPI-off motion of stage 1
% this is the HEPI motion at LASTI times the LLO ground motion scaling.
LLO_HEPIX_estimate_raw = LLO_groundX_scaling .* BSCdataASPEpaper.XHEPI.ASDdata';
% this is a really big freq vector! too big to be useful, really
%
stage1.freq = logspace(-1,2,500)';
LLO_HEPIX_estimate = interp1(GS13stg2freeRMS.freq, LLO_HEPIX_estimate_raw, stage1.freq);

ground_motion_LLO_stage1freq = Ligo2GroundMotionL(stage1.freq);
%%

figure
loglog(GS13stg2freeRMS.freq, LLO_HEPIX_estimate_raw,...
    stage1.freq, LLO_HEPIX_estimate);
grid on
xlabel('freq (Hz)')
title('HEPI-off stage 0 motion estimate from scaling LASTI')
ylabel('motion ASD (m/rtHz)')
axis([.1 30 1e-10 1e-5])
%%
% load up the model of the BSC from BTLs old code, using 'as-build'
% numbers, and a guess at the damping.
% loads the variables:
% in:                 list of inputs
% out:                list of outputs
% plant_noControl:    SS model of just the mechanical plant, stage 0 to stage 1 and 2
% plant_dampingOnly:  SS model of plant with damping on and isolation off
% note:               file creation info

load('BSCplant_BTLguess_100329.mat')

%%
disp('calculating the BSC plant')
tic
plant_noControl_FR   = freqresp(plant_noControl,   2*pi*stage1.freq);
plant_dampingOnly_FR = freqresp(plant_dampingOnly, 2*pi*stage1.freq);
calc_time = toc;
disp(['   finished in ',num2str(calc_time),' seconds'])

%% and now make the stage 1 motion
stage1.motionX_noControl   = LLO_HEPIX_estimate .* abs(squeeze(plant_noControl_FR(  out.stage1_x, in.gnd_x,:))) ;
stage1.motionX_dampingOnly = LLO_HEPIX_estimate .* abs(squeeze(plant_dampingOnly_FR(out.stage1_x, in.gnd_x,:)));

stage2.motionX_noControl   = LLO_HEPIX_estimate .* abs(squeeze(plant_noControl_FR(  out.stage2_x, in.gnd_x,:))) ;
stage2.motionX_dampingOnly = LLO_HEPIX_estimate .* abs(squeeze(plant_dampingOnly_FR(out.stage2_x, in.gnd_x,:)));

% this is still on the long freq vector, not the short one...
stage2.motionX_noControl_scaled_from_LASTI_raw = LLO_groundX_scaling .* BSCdataASPEpaper.XISI_free.ASDdata';

stage2.motionX_noControl_scaled_from_LASTI = interp1(...
    BSCdataASPEpaper.XISI_free.freq, stage2.motionX_noControl_scaled_from_LASTI_raw, stage1.freq);

%%
fig_LLO_motion_stg0_est = figure;
ll = loglog(...
    stage1.freq, ground_motion_LLO_stage1freq,'g',...
    stage1.freq, LLO_HEPIX_estimate,'b');
set(ll,'LineWidth',2)
grid on
xlabel('freq (Hz)')
title('HEPI-off stage 0 motion estimate from scaling LASTI')
ylabel('motion ASD (m/rtHz)')
axis([.1 30 1e-10 3e-6])
FillPage('w')
IDfig

%%
fig_LLO_motion_stg1_est = figure;
ll = loglog(...
    stage1.freq, ground_motion_LLO_stage1freq,'g',...
    stage1.freq, stage1.motionX_noControl,'r--',...
    stage1.freq, stage1.motionX_dampingOnly,'r');
set(ll,'LineWidth',2)
set(ll(2),'LineWidth',3)
grid on
xlabel('freq (Hz)')
title('HEPI-off stage 1 horizontal motion estimate from scaling model * LASTI HEPI motion')
ylabel('motion ASD (m/rtHz)')
legend('LLO ground','Stage 1 estimate - no damping','stage 1 estimate - well damped')
axis([.1 30 1e-10 3e-6])
FillPage('w')
IDfig

%%
fig_LLO_motion_stg2_est = figure;
ll = loglog(...
    stage1.freq, ground_motion_LLO_stage1freq,'g',...
    stage1.freq, stage2.motionX_dampingOnly,'m',...
    stage1.freq, stage2.motionX_noControl,'k--',...
    stage1.freq, stage2.motionX_noControl_scaled_from_LASTI,'m--');
set(ll,'LineWidth',2)
set(ll(3),'LineWidth',3)
set(ll(4),'LineWidth',3)
grid on
xlabel('freq (Hz)')
title('HEPI-off stage 2 horizontal motion estimates')
ylabel('motion ASD (m/rtHz)')
legend('LLO ground',...
    'scaled stage 0, HEPI off * damped model',...
    'scaled stage 0, HEPI off * model w/ no damping',...
    'scaled motion of LASTI with no damping')
axis([.1 30 1e-10 3e-6])
FillPage('w')
IDfig

%% get the L-4Cs for the feedforward

L4C_FFrms.freq = stage1.freq;

L4C_FFrms.L4Cresp = abs(squeeze(freqresp(L4C.lowgain_volt_per_m,2*pi*L4C_FFrms.freq)));

L4C_FFrms.X_ADC_asd = L4C_FFrms.L4Cresp .* LLO_HEPIX_estimate;

L4C_FFrms.X_rms = reverse(sqrt(cumsum(reverse(L4C_FFrms.X_ADC_asd.^2))));


%%
L4C_stg0_range_fig = figure;
ll=loglog(...
    L4C_FFrms.freq, L4C_FFrms.X_ADC_asd,'b',...
    L4C_FFrms.freq, L4C_FFrms.X_rms,'b--');
set(ll,'linewidth',2);
title({'Estimated Signal levels from the BSC-ISI stage 0 FF L-4C','scaled LASTI HEPI motion, at the ADC in low-gain mode'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.1 100 1e-4 1])
set(gca,'YTick',[1e-4, 1e-3, 1e-2, 1e-1, 1])
leg = legend(...
    'ASD of horizontal L-4C','integrated RMS of horizontal L-4C',...
    'Location','South');
set(leg,'FontSize',18);
FillPage('w')
IDfig



%% get the L-4Cs for stage 1

L4C_stg1rms.freq = stage1.freq;
% L4C_FFrms.Zfreq = BSCdataASPEpaper.ZHEPI.freq;  % again, these are the same

L4C_stg1rms.L4Cresp_lowgain = abs(squeeze(freqresp(L4C.lowgain_volt_per_m, 2*pi * L4C_stg1rms.freq)));
L4C_stg1rms.L4Cresp_highgain = abs(squeeze(freqresp(L4C.highgain_volt_per_m, 2*pi * L4C_stg1rms.freq)));

L4C_stg1rms.X_ADC_asd_free   = L4C_stg1rms.L4Cresp_lowgain  .* stage1.motionX_noControl;
L4C_stg1rms.X_ADC_asd_damped = L4C_stg1rms.L4Cresp_highgain .* stage1.motionX_dampingOnly;

% rms of the signal at the ADC, HAM6ISI from the lowgain GS13
L4C_stg1rms.Xrms_free = reverse(sqrt(cumsum(reverse(L4C_stg1rms.X_ADC_asd_free.^2))));
L4C_stg1rms.Xrms_damped = reverse(sqrt(cumsum(reverse(L4C_stg1rms.X_ADC_asd_damped.^2))));


%%
L4C_stg1_range_fig = figure;
ll=loglog(...
    L4C_stg1rms.freq, L4C_stg1rms.X_ADC_asd_free,'b',...
    L4C_stg1rms.freq, L4C_stg1rms.Xrms_free,'b--',...
    L4C_stg1rms.freq, L4C_stg1rms.X_ADC_asd_damped,'r',...
    L4C_stg1rms.freq, L4C_stg1rms.Xrms_damped,'r--');
set(ll,'linewidth',2);
set(ll(3),'Color',purple)
set(ll(4),'Color',purple)

title({'Estimated Signal levels for BSC stage 1 L-4C','Measured at the ADC'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.1 100 1e-5 10])
set(gca,'YTick',[1e-5, 1e-4, 1e-3, 1e-2, 1e-1, 1, 10])
leg = legend(...
    'ASD of horizontal L-4C - no damping, low-gain','integrated RMS of L-4C - no damping, low-gain',...
    'ASD of L-4C - damping on, high gain','integrated RMS of L-4C - damping on, high gain',...
    'Location','NorthEast');
set(leg,'FontSize',18);
FillPage('w')
IDfig


%% get the T240s for stage 1

T240rms.freq = stage1.freq;

T240rms.T240resp = abs(squeeze(freqresp(T240.volt_per_m, 2*pi * T240rms.freq)));

T240rms.X_ADC_asd_free   = T240rms.T240resp .* stage1.motionX_noControl;
T240rms.X_ADC_asd_damped = T240rms.T240resp .* stage1.motionX_dampingOnly;

% rms of the signal at the ADC, HAM6ISI from the lowgain GS13
T240rms.Xrms_free   = reverse(sqrt(cumsum(reverse(T240rms.X_ADC_asd_free.^2))));
T240rms.Xrms_damped = reverse(sqrt(cumsum(reverse(T240rms.X_ADC_asd_damped.^2))));


%%
T240_range_fig = figure;
ll=loglog(...
    T240rms.freq, T240rms.X_ADC_asd_free,'b',...
    T240rms.freq, T240rms.Xrms_free,'b--',...
    T240rms.freq, T240rms.X_ADC_asd_damped,'m',...
    T240rms.freq, T240rms.Xrms_damped,'m--');
set(ll,'linewidth',2);
title({'Estimated Signal levels for BSC-ISI stage 1 T-240','horizontal motion at LLO, measured at the ADC'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.05 100 1e-5 10])
set(gca,'YTick',[1e-4, 1e-3, 1e-2, 1e-1, 1, 10])
leg = legend(...
    'estimated ASD of horizontal stage 1 T240 - HEPI OFF, damping OFF','integrated RMS of T240 - HEPI OFF, damping OFF',...
    'ASD of T240 - HEPI OFF, damping ON','integrated RMS of T240 - HEPI OFF, damping ON',...
    'Location','SouthWest');
set(leg,'FontSize',18);
FillPage('w')
IDfig



%%
GS13stg2RMS.freq  = stage1.freq;
GS13stg2RMS.GS13resp_lowgain  = abs(squeeze(freqresp(GS13.lowgain_volt_per_m, 2*pi*GS13stg2RMS.freq)));
GS13stg2RMS.GS13resp_highgain = abs(squeeze(freqresp(GS13.highgain_volt_per_m,2*pi*GS13stg2RMS.freq)));


% estimate for the undamped motion of stage 2, seen by GS-13s, 
% first use the scaled LASTI data, then do the modeled motion (we will see
% if they are similar)
GS13stg2RMS.X_ADC_asd_free_scaled_from_LASTI = GS13stg2RMS.GS13resp_lowgain .* stage2.motionX_noControl_scaled_from_LASTI ;
GS13stg2RMS.X_ADC_asd_free_modeled =           GS13stg2RMS.GS13resp_lowgain .* stage2.motionX_noControl;

% rms of the signals at the ADC
GS13stg2RMS.Xrms_free_scaled_from_LASTI = reverse(sqrt(cumsum(reverse(GS13stg2RMS.X_ADC_asd_free_scaled_from_LASTI.^2))));
GS13stg2RMS.Xrms_free_modeled           = reverse(sqrt(cumsum(reverse(GS13stg2RMS.X_ADC_asd_free_modeled.^2))));

% and look with the damping ON
GS13stg2RMS.X_ADC_asd_damped_modeled = GS13stg2RMS.GS13resp_highgain .* stage2.motionX_dampingOnly;
GS13stg2RMS.Xrms_damped_modeled      = reverse(sqrt(cumsum(reverse(GS13stg2RMS.X_ADC_asd_damped_modeled.^2))));


% and finally at the signal if the motion is at the requirement level 
GS13stg2RMS.BSC_req = BSC_req(GS13stg2RMS.freq);

GS13stg2RMS.X_ADC_asd_req  = GS13stg2RMS.GS13resp_highgain .* GS13stg2RMS.BSC_req;
GS13stg2RMS.Xrms_req       = reverse(sqrt(cumsum(reverse(GS13stg2RMS.X_ADC_asd_req.^2))));

%%
GS13stg2_free_range_fig = figure;
ll=loglog(...
    GS13stg2RMS.freq, GS13stg2RMS.X_ADC_asd_free_scaled_from_LASTI,'b',...
    GS13stg2RMS.freq, GS13stg2RMS.Xrms_free_scaled_from_LASTI,'b--',...
    GS13stg2RMS.freq, GS13stg2RMS.X_ADC_asd_free_modeled,'m',...
    GS13stg2RMS.freq, GS13stg2RMS.Xrms_free_modeled,'m--');
set(ll,'LineWidth',2)
title({'Expected Signal levels from the horizontal GS-13s on the BSC','No damping, HEPI off, at the ADC in low-gain mode'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.1 100 1e-6 30])
leg = legend(...
    'ASD of GS-13 - scaled from LASTI','integrated RMS - scaled from LASTI',...
    'ASD of GS-13 - modeled','integrated RMS - modeled',...
    'Location','SouthWest');
set(leg,'FontSize',18);
FillPage('w')
IDfig



%%
GS13stg2_damped_range_fig = figure;
ll=loglog(...
    GS13stg2RMS.freq, GS13stg2RMS.X_ADC_asd_free_scaled_from_LASTI,'b',...
    GS13stg2RMS.freq, GS13stg2RMS.Xrms_free_scaled_from_LASTI,'b--',...
    GS13stg2RMS.freq, GS13stg2RMS.X_ADC_asd_damped_modeled,'m',...
    GS13stg2RMS.freq, GS13stg2RMS.Xrms_damped_modeled,'m--',...
    GS13stg2RMS.freq, GS13stg2RMS.X_ADC_asd_req,'r',...
    GS13stg2RMS.freq, GS13stg2RMS.Xrms_req,'r--');
set(ll,'LineWidth',2)
set(ll(3),'Color',purple)
set(ll(4),'Color',purple)
set(ll(5),'Color',dark_orange)
set(ll(6),'Color',dark_orange)

title({'Expected Signal levels from the horizontal GS-13s on the BSC','HEPI off, at the ADC'})
xlabel('freq (Hz)')
ylabel('ASD volts (V/rtHz) or integrated rms')
grid on
axis([0.1 100 1e-7 30])
set(gca,'Ytick',[1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1 10])
leg = legend(...
    'ASD, low gain, No damping, scaled from LASTI stage 2','int. RMS - low gain, No damping, scaled from LASTI',...
    'ASD, high gain, damping only, model with scaled HEPI from LASTI','RMS -  high gain, damping only, model with scaled HEPI from LASTI',...
    'ASD, high gain, BSC requirements','RMS - high gain, BSC requirements',...
    'Location','SouthWest');
set(leg,'FontSize',16);
FillPage('w')
IDfig


%%
if printRMSFigs == true
    
    figure( fig_LLO_motion_stg0_est)
    filename = ['RMSFigs_stage0_motion_',date_str,'.pdf'];
    print(fig_LLO_motion_stg0_est, '-dpdf', filename)

    figure( fig_LLO_motion_stg1_est)
    filename = ['RMSFigs_stage1_motion_',date_str,'.pdf'];
    print(fig_LLO_motion_stg1_est, '-dpdf', filename)

    figure( fig_LLO_motion_stg2_est)
    filename = ['RMSFigs_stage2_motion_',date_str,'.pdf'];
    print(fig_LLO_motion_stg2_est, '-dpdf', filename)

    figure( GS13HAM_range_fig)
    filename = ['RMSFigs_HAMGS13_LLO_free_motion_',date_str,'.pdf'];
    print(GS13HAM_range_fig, '-dpdf', filename)

    figure( GS13HAM_damped_range_fig)
    filename = ['RMSFigs_HAMGS13_LLO_damped_motion_',date_str,'.pdf'];
    print(GS13HAM_damped_range_fig, '-dpdf', filename)
    
    figure(L4C_stg0_range_fig)
    filename = ['RMSFigs_L4CFF_stg0_motion_',date_str,'.pdf'];
    print(L4C_stg0_range_fig, '-dpdf', filename)
    
    figure(L4C_stg1_range_fig)
    filename = ['RMSFigs_L4Cstg1_motion_',date_str,'.pdf'];
    print(L4C_stg1_range_fig, '-dpdf', filename)

    figure(T240_range_fig)
    filename = ['RMSFigs_T240_motion_',date_str,'.pdf'];
    print(T240_range_fig, '-dpdf', filename)

    figure(GS13stg2_free_range_fig)
    filename = ['RMSFigs_GS13stg2_free_motion_',date_str,'.pdf'];
    print(GS13stg2_free_range_fig, '-dpdf', filename)

    figure(GS13stg2_damped_range_fig)
    filename = ['RMSFigs_GS13stg2_damped_motion_',date_str,'.pdf'];
    print(GS13stg2_damped_range_fig, '-dpdf', filename)

end


